==> mule-soap-engine-1.2.0-sources.jar: org/mule/soap/internal/util/XmlTransformationUtils.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.soap.internal.util;

import com.ctc.wstx.stax.WstxInputFactory;
import net.sf.saxon.jaxp.SaxonTransformerFactory;
import org.mule.soap.internal.xml.stax.StaxSource;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.xml.sax.InputSource;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.stream.XMLInputFactory;
import javax.xml.stream.XMLStreamReader;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMResult;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import java.io.ByteArrayInputStream;
import java.io.StringReader;
import java.io.StringWriter;
import java.nio.charset.Charset;

import static javax.xml.stream.XMLInputFactory.IS_COALESCING;

/**
 *
 * @since 1.0
 */
public class XmlTransformationUtils {

  private static final XMLInputFactory XML_INPUT_FACTORY = getXmlInputFactory();
  private static final DocumentBuilderFactory DOC_BUILDER_FACTORY = getDocumentBuilderFactory();

  private static DocumentBuilderFactory getDocumentBuilderFactory() {
    DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
    documentBuilderFactory.setNamespaceAware(true);
    return documentBuilderFactory;
  }

  private static final TransformerFactory SAXON_TRANSFORMER_FACTORY = SaxonTransformerFactory.newInstance();

  private static XMLInputFactory getXmlInputFactory() {
    XMLInputFactory xmlInputFactory = WstxInputFactory.newInstance();
    // Preserve the CDATA tags
    xmlInputFactory.setProperty(IS_COALESCING, false);
    return xmlInputFactory;
  }

  public static Document xmlStreamReaderToDocument(XMLStreamReader xmlStreamReader) throws XmlTransformationException {
    StaxSource staxSource = new StaxSource(xmlStreamReader);
    DOMResult writer = new DOMResult();
    try {
      Transformer transformer = SAXON_TRANSFORMER_FACTORY.newTransformer();
      transformer.transform(staxSource, writer);
    } catch (TransformerException e) {
      throw new XmlTransformationException("Error transforming reader to DOM document", e);
    }
    return (Document) writer.getNode();
  }

  public static Element stringToDomElement(String xml) throws XmlTransformationException {
    try {
      DocumentBuilder db = DOC_BUILDER_FACTORY.newDocumentBuilder();
      InputSource is = new InputSource();
      is.setCharacterStream(new StringReader(xml));
      return db.parse(is).getDocumentElement();
    } catch (Exception e) {
      throw new XmlTransformationException("Could not transform xml string to Dom Element", e);
    }
  }

  public static Document stringToDocument(String xml) throws XmlTransformationException {
    try {
      DocumentBuilder builder = DOC_BUILDER_FACTORY.newDocumentBuilder();
      return builder.parse(new ByteArrayInputStream(xml.getBytes()));
    } catch (Exception e) {
      throw new XmlTransformationException("Could not transform xml to Dom Document", e);
    }
  }

  public static String nodeToString(Node node) throws XmlTransformationException {
    try {
      StringWriter writer = new StringWriter();
      DOMSource source = new DOMSource(node);
      StreamResult result = new StreamResult(writer);
      Transformer transformer = SAXON_TRANSFORMER_FACTORY.newTransformer();
      transformer.transform(source, result);
      return writer.toString();
    } catch (Exception e) {
      throw new XmlTransformationException("Could not transform Node to String", e);
    }
  }

  public static XMLStreamReader stringToXmlStreamReader(String xml) throws XmlTransformationException {
    return stringToXmlStreamReader(xml, "UTF-8");
  }

  public static XMLStreamReader stringToXmlStreamReader(String xml, String encoding) throws XmlTransformationException {
    try {
      return XML_INPUT_FACTORY.createXMLStreamReader(new ByteArrayInputStream(xml.getBytes(Charset.forName(encoding))));
    } catch (Exception e) {
      throw new XmlTransformationException("Could not transform xml to XmlStreamReader", e);
    }
  }
}

==> mule-soap-engine-1.3.5-sources.jar: org/mule/soap/internal/util/XmlTransformationUtils.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.soap.internal.util;

import static javax.xml.stream.XMLInputFactory.IS_COALESCING;

import org.mule.soap.internal.xml.stax.StaxSource;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.io.StringReader;
import java.io.StringWriter;
import java.nio.charset.Charset;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.stream.XMLInputFactory;
import javax.xml.stream.XMLStreamReader;
import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMResult;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import com.ctc.wstx.stax.WstxInputFactory;
import net.sf.saxon.jaxp.SaxonTransformerFactory;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.xml.sax.InputSource;

/**
 *
 * @since 1.0
 */
public class XmlTransformationUtils {

  private static final XMLInputFactory XML_INPUT_FACTORY = getXmlInputFactory();
  private static final DocumentBuilderFactory DOC_BUILDER_FACTORY = getDocumentBuilderFactory();

  private static DocumentBuilderFactory getDocumentBuilderFactory() {
    DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
    documentBuilderFactory.setNamespaceAware(true);
    return documentBuilderFactory;
  }

  private static final TransformerFactory SAXON_TRANSFORMER_FACTORY = SaxonTransformerFactory.newInstance();

  private static XMLInputFactory getXmlInputFactory() {
    XMLInputFactory xmlInputFactory = WstxInputFactory.newInstance();
    // Preserve the CDATA tags
    xmlInputFactory.setProperty(IS_COALESCING, false);
    return xmlInputFactory;
  }

  public static Document xmlStreamReaderToDocument(XMLStreamReader xmlStreamReader) throws XmlTransformationException {
    StaxSource staxSource = new StaxSource(xmlStreamReader);
    DOMResult writer = new DOMResult();
    try {
      Transformer transformer = SAXON_TRANSFORMER_FACTORY.newTransformer();
      transformer.transform(staxSource, writer);
    } catch (TransformerException e) {
      throw new XmlTransformationException("Error transforming reader to DOM document", e);
    }
    return (Document) writer.getNode();
  }

  public static InputStream documentToInputStream(Document document) throws XmlTransformationException {
    try {
      ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
      Source xmlSource = new DOMSource(document);
      Result outputTarget = new StreamResult(outputStream);
      SAXON_TRANSFORMER_FACTORY.newTransformer().transform(xmlSource, outputTarget);
      return new ByteArrayInputStream(outputStream.toByteArray());
    } catch (TransformerException e) {
      throw new XmlTransformationException("Error transforming Document to Stream", e);
    }
  }

  public static Element stringToDomElement(String xml) throws XmlTransformationException {
    try {
      DocumentBuilder db = DOC_BUILDER_FACTORY.newDocumentBuilder();
      InputSource is = new InputSource();
      is.setCharacterStream(new StringReader(xml));
      return db.parse(is).getDocumentElement();
    } catch (Exception e) {
      throw new XmlTransformationException("Could not transform xml string to Dom Element", e);
    }
  }

  public static Document stringToDocument(String xml) throws XmlTransformationException {
    try {
      DocumentBuilder builder = DOC_BUILDER_FACTORY.newDocumentBuilder();
      return builder.parse(new ByteArrayInputStream(xml.getBytes()));
    } catch (Exception e) {
      throw new XmlTransformationException("Could not transform xml to Dom Document", e);
    }
  }

  public static String nodeToString(Node node) throws XmlTransformationException {
    try {
      StringWriter writer = new StringWriter();
      DOMSource source = new DOMSource(node);
      StreamResult result = new StreamResult(writer);
      Transformer transformer = SAXON_TRANSFORMER_FACTORY.newTransformer();
      transformer.transform(source, result);
      return writer.toString();
    } catch (Exception e) {
      throw new XmlTransformationException("Could not transform Node to String", e);
    }
  }

  public static XMLStreamReader stringToXmlStreamReader(String xml) throws XmlTransformationException {
    return stringToXmlStreamReader(xml, "UTF-8");
  }

  public static XMLStreamReader stringToXmlStreamReader(String xml, String encoding) throws XmlTransformationException {
    try {
      return XML_INPUT_FACTORY.createXMLStreamReader(new ByteArrayInputStream(xml.getBytes(Charset.forName(encoding))));
    } catch (Exception e) {
      throw new XmlTransformationException("Could not transform xml to XmlStreamReader", e);
    }
  }
}
